@@ -1,7 +1,7 @@
 __title__ = 'admin_timeline.conf'
-__version__ = '1.2'
-__build__ = 0x00000c
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__copyright__ = 'Copyright (c) 2013 Artur Barseghyan'
+__license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('get_setting',)
 
 from django.conf import settings
@@ -20,7 +20,8 @@ def get_setting(setting, override=None):
     """
     if override is not None:
         return override
-    if hasattr(settings, 'ADMIN_TIMELINE_%s' % setting):
-        return getattr(settings, 'ADMIN_TIMELINE_%s' % setting)
+    _setting = 'ADMIN_TIMELINE_{0}'.format(setting)
+    if hasattr(settings, _setting):
+        return getattr(settings, _setting)
     else:
         return getattr(defaults, setting)
