@@ -4,10 +4,10 @@ __copyright__ = 'Copyright (c) 2013 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('log',)
 
+import json
 import datetime
 
 from django.http import HttpResponse
-from django.utils import simplejson as json
 from django.views.decorators.cache import never_cache
 from django.contrib.admin.views.decorators import staff_member_required
 from django.contrib.admin.models import LogEntry
@@ -18,27 +18,35 @@ from django.template.defaultfilters import date as date_format
 from django.utils.translation import ugettext_lazy as _
 from django.views.decorators.csrf import csrf_exempt
 
-from admin_timeline.settings import NUMBER_OF_ENTRIES_PER_PAGE, SINGLE_LOG_ENTRY_DATE_FORMAT
+from admin_timeline.settings import (
+    NUMBER_OF_ENTRIES_PER_PAGE, SINGLE_LOG_ENTRY_DATE_FORMAT
+    )
 from admin_timeline.settings import LOG_ENTRIES_DAY_HEADINGS_DATE_FORMAT
 from admin_timeline.forms import FilterForm
+from admin_timeline.compat import TEMPLATE_NAME, TEMPLATE_NAME_AJAX
 
 @csrf_exempt
 @never_cache
 @staff_member_required
-def log(request, template_name="admin_timeline/timeline.html", template_name_ajax="admin_timeline/timeline_ajax.html"):
+def log(request, template_name=TEMPLATE_NAME, \
+        template_name_ajax=TEMPLATE_NAME_AJAX):
     """
     Get number of log entires. Serves both non-AJAX and AJAX driven requests.
 
-    Since we have a breakdown of entries per day per entry and we have an AJAX driven infinite scroll and we want to
-    avoid having duplicated date headers, we always pass a variable named "last_date" when making another request
+    Since we have a breakdown of entries per day per entry and we have an AJAX
+    driven infinite scroll and we want to avoid having duplicated date headers,
+    we always pass a variable named "last_date" when making another request
     to our main AJAX-driven view. So... this is our case scenario:
 
-    Initial timeline rendered as a normal HTML (non AJAX request) (from a list of log entries). We send date of
-    last element as "last_date" to the context too, which will be used an an initial value for a global JavaScript
-    variable. Later on that date will be used to send it to the AJAX driven view and used in
-    rendering ("render_to_string" method). After we have rendered the HTML to send back, we get the last date of
-    the last element and send it along with the HTML rendered to our view in JSON response. When receiving the
-    JSON response, we update the above mentioned global JavaScript variable with the value given.
+    Initial timeline rendered as a normal HTML (non AJAX request) (from a list
+    of log entries). We send date of last element as "last_date" to the context
+    too, which will be used an an initial value for a global JavaScript
+    variable. Later on that date will be used to send it to the AJAX driven
+    view and used in rendering ("render_to_string" method). After we have
+    rendered the HTML to send back, we get the last date of the last element
+    and send it along with the HTML rendered to our view in JSON response.
+    When receiving the JSON response, we update the above mentioned global
+    JavaScript variable with the value given.
 
     :param request: django.http.HttpRequest
     :param template_name: str
@@ -49,10 +57,13 @@ def log(request, template_name="admin_timeline/timeline.html", template_name_aja
     :param page: int - Page number to get.
     :param user_id: int - If set, used to filter the user by.
     :param last_date: str - Example value "2012-05-24".
-    :param start_date: str - If set, used as a start date to filter the actions with. Example value "2012-05-24".
-    :param end_date: str - If set, used as an end date to filter the actions with. Example value "2012-05-24".
+    :param start_date: str - If set, used as a start date to filter the actions
+        with. Example value "2012-05-24".
+    :param end_date: str - If set, used as an end date to filter the actions
+        with. Example value "2012-05-24".
 
-    NOTE: If it gets too complicatd with filtering, we need to have forms to validate and process the POST data.
+    NOTE: If it gets too complicatd with filtering, we need to have forms to
+    validate and process the POST data.
     """
     def _get_date_from_string(s):
         """
@@ -121,7 +132,9 @@ def log(request, template_name="admin_timeline/timeline.html", template_name_aja
     log_entries = log_entries[start:end]
 
     if log_entries:
-        last_date = date_format(log_entries[len(log_entries) - 1].action_time, "Y-m-d")
+        last_date = date_format(
+            log_entries[len(log_entries) - 1].action_time, "Y-m-d"
+            )
     else:
         last_date = request.POST.get('last_date', None)
 
@@ -134,7 +147,8 @@ def log(request, template_name="admin_timeline/timeline.html", template_name_aja
             'page': page,
             'last_date': request.POST.get('last_date', None),
             'SINGLE_LOG_ENTRY_DATE_FORMAT': SINGLE_LOG_ENTRY_DATE_FORMAT,
-            'LOG_ENTRIES_DAY_HEADINGS_DATE_FORMAT': LOG_ENTRIES_DAY_HEADINGS_DATE_FORMAT
+            'LOG_ENTRIES_DAY_HEADINGS_DATE_FORMAT': \
+                LOG_ENTRIES_DAY_HEADINGS_DATE_FORMAT
         }
 
         # Rendering HTML for an AJAX driven request
@@ -164,8 +178,11 @@ def log(request, template_name="admin_timeline/timeline.html", template_name_aja
         'content_types': [int(ct) for ct in content_types],
         'filter_form': filter_form,
         'SINGLE_LOG_ENTRY_DATE_FORMAT': SINGLE_LOG_ENTRY_DATE_FORMAT,
-        'LOG_ENTRIES_DAY_HEADINGS_DATE_FORMAT': LOG_ENTRIES_DAY_HEADINGS_DATE_FORMAT,
+        'LOG_ENTRIES_DAY_HEADINGS_DATE_FORMAT': \
+            LOG_ENTRIES_DAY_HEADINGS_DATE_FORMAT,
         'title': _("Timeline") # For template breadcrumbs, etc.
     }
 
-    return render_to_response(template_name, context, context_instance=RequestContext(request))
+    return render_to_response(
+        template_name, context, context_instance=RequestContext(request)
+        )
